==> plasma-phone-components-5.17.90.tar.xz: plasma-phone-components-5.17.90/containments/homescreen/colouraverage.h <==
/***************************************************************************
 *   Copyright (C) 2019 Carson Black                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#include <QObject>
#include <QColor>
#include <QImage>

class ColourAverage : public QObject
{
    Q_OBJECT
public:
    explicit ColourAverage(QObject* parent = nullptr);
    Q_INVOKABLE QColor averageColour(QImage img);
};

==> plasma-phone-components-5.19.1.tar.xz: plasma-phone-components-5.19.1/containments/homescreen/colouraverage.h <==
/***************************************************************************
 *   Copyright (C) 2019 Carson Black <uhhadd@gmail.com>                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/
#pragma once

#include <QObject>
#include <QColor>
#include <QImage>

class ColourAverage : public QObject
{
    Q_OBJECT

public:
    explicit ColourAverage(QObject *parent = nullptr);
    Q_INVOKABLE QColor averageColour(const QImage &img);
};
